summaryrefslogtreecommitdiff
path: root/regnodes.h
diff options
context:
space:
mode:
Diffstat (limited to 'regnodes.h')
-rw-r--r--regnodes.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/regnodes.h b/regnodes.h
index 4d476b9ebc..17314e3e1a 100644
--- a/regnodes.h
+++ b/regnodes.h
@@ -1982,12 +1982,12 @@ EXTCONST U8 PL_regnode_arg_len_varies[] = {
#endif /* DOINIT */
/* PL_reg_off_by_arg[] - Which argument holds the offset to the next node */
#ifndef DOINIT
-EXTCONST U8 PL_reg_off_by_arg[];
+EXTCONST U8 PL_regnode_off_by_arg[];
#else
-EXTCONST U8 PL_reg_off_by_arg[] = {
+EXTCONST U8 PL_regnode_off_by_arg[] = {
0, /* END */
0, /* SUCCEED */
0, /* SBOL */
@@ -1982,12 +1982,12 @@ EXTCONST U8 PL_regnode_arg_len_varies[] = {
#endif /* DOINIT */
-/* PL_reg_off_by_arg[] - Which argument holds the offset to the next node */
+/* PL_regnode_off_by_arg[] - Which argument holds the offset to the next node */
#ifndef DOINIT